@@ -18,26 +18,38 @@ class plastimatch1_EXPORT Autolabel_trainer
     ~Autolabel_trainer ();
 
   public:
+    Pstring m_output_dir;
     std::string m_input_dir;
     std::string m_task;
 
   private:
-    Dlib_trainer *m_dt;
+    Dlib_trainer *m_dt_tsv1;
+    Dlib_trainer *m_dt_tsv2_x;
+    Dlib_trainer *m_dt_tsv2_y;
+    Dlib_trainer *m_dt_la1;
 
   public:
-    void save_csv (const char* output_csv_fn);
-    void save_tsacc (const Pstring& output_tsacc_fn);
+    void load_inputs ();
+    void save_csv ();
+    void save_tsacc ();
     void set_input_dir (const char* input_dir);
     void set_task (const char* task);
-    void train (const Pstring& output_net_fn);
+    void train ();
 
   private:
-    void load_inputs ();
     void load_input_dir_recursive (std::string input_dir);
     void load_input_file (const char* nrrd_fn, const char* fcsv_fn);
-    void load_input_file_la (const char* nrrd_fn, const char* fcsv_fn);
-    void load_input_file_tsv1 (const char* nrrd_fn, const char* fcsv_fn);
-    void load_input_file_tsv2 (const char* nrrd_fn, const char* fcsv_fn);
 };
 
+class plastimatch1_EXPORT Autolabel_train_parms {
+public:
+    Pstring input_dir;
+    Pstring output_dir;
+    Pstring task;
+};
+
+plastimatch1_EXPORT 
+void
+autolabel_train (Autolabel_train_parms *parms);
+
 #endif
