@@ -711,11 +711,11 @@ void dump_xpm_hist (BSPLINE_MI_Hist* mi_hist, char* file_base, int iter)
     int graph_bar_height = 100;
     int graph_bar_width = 5;
     int graph_bar_spacing = (int)((float)graph_bar_width * (7.0/5.0));
-    int graph_color_levels = 22;
+    size_t graph_color_levels = 22;
 
     //  int fixed_bar_height;   // max bar height (pixels)
     //  int moving_bar_height;
-    int joint_color;
+    size_t joint_color;
 
     float fixed_scale;  // pixels per amt
     float moving_scale;
@@ -859,7 +859,7 @@ void dump_xpm_hist (BSPLINE_MI_Hist* mi_hist, char* file_base, int iter)
     z = 0;
     for(j=0; j<mi_hist->fixed.bins; j++) {
         for(i=0; i<mi_hist->moving.bins; i++) {
-            joint_color = (int)(j_hist[z++] * joint_scale);
+            joint_color = (size_t)(j_hist[z++] * joint_scale);
             if (joint_color > 0) {
                 // special handling for bin 0
                 if (joint_color > graph_color_levels) {
@@ -1442,8 +1442,7 @@ bspline_mi_pvi_6_dc_dv (
    ----------------------------------------------------------------------- */
 
 /* JAS 2010.11.30
- * This is an intentionally bad idea and will be removed as soon the paper I'm
- * writing sees some ink.
+ * This is an intentionally bad idea -- proof of concept code
  * 
  * B-Spline Registration using Mutual Information
  * Implementation F (not good... only for comparison to E)
@@ -1926,7 +1925,7 @@ bspline_score_e_mi (
 
     /* Fill in the missing jnt hist bin */
     for (long j=0; j<mi_hist->fixed.bins; j++) {
-        for (long i=0; i<mi_hist->moving.bins; i++) {
+        for (unsigned long i=0; i<mi_hist->moving.bins; i++) {
             jhis += j_hist[j*mi_hist->moving.bins + i];
         }
     }
@@ -1936,7 +1935,7 @@ bspline_score_e_mi (
     /* Look for the biggest joint histogram bin */
 //    printf ("joint.big_bin [%i -> ", mi_hist->joint.big_bin);
     for (long j=0; j<mi_hist->fixed.bins; j++) {
-        for (long i=0; i<mi_hist->moving.bins; i++) {
+        for (unsigned long i=0; i<mi_hist->moving.bins; i++) {
             if (j_hist[j*mi_hist->moving.bins + i] > j_hist[mi_hist->joint.big_bin]) {
                 mi_hist->joint.big_bin = j*mi_hist->moving.bins + i;
             }
@@ -1954,7 +1953,7 @@ bspline_score_e_mi (
     /* Display histrogram stats in debug mode */
     if (parms->debug) {
         double tmp;
-	long zz;
+        long zz;
         for (zz=0,tmp=0; zz < mi_hist->fixed.bins; zz++) {
             tmp += f_hist[zz];
         }
