@@ -20,7 +20,7 @@
 
 /* Prototypes */
 static void bspline_xform_create_qlut_grad (
-    Bspline_xform* bxf, float img_spacing[3], int vox_per_rgn[3]);
+    Bspline_xform* bxf, float img_spacing[3], size_t vox_per_rgn[3]);
 static void bspline_xform_free_qlut_grad (Bspline_xform* bxf);
 
 /* Flavor 'a' */
@@ -37,7 +37,10 @@ vf_regularize_numerical (
     FILE* fp[3];
 #endif
 
-    int i,j,k,c;
+    Plm_timer timer;
+
+    size_t i, j, k;
+    int c;
     float *img = (float*) vol->img;
 
     float dx = vol->spacing[0];
@@ -101,6 +104,8 @@ vf_regularize_numerical (
     printf ("  d2uz_dxy_sq.txt\n"); fp[2] = fopen ("d2uz_dxdy_sq.txt", "w");
 #endif
 
+    plm_timer_start (&timer);
+
     S = 0.0f;
     for (k = 1; k < vol->dim[2]-1; k++) {
         for (j = 1; j < vol->dim[1]-1; j++) {
@@ -301,6 +306,7 @@ vf_regularize_numerical (
 #endif
 
     bscore->rmetric += S;
+    bscore->time_rmetric = plm_timer_report (&timer);
 }
 
 void
@@ -339,9 +345,9 @@ void bspline_xform_create_qlut_grad
 (
     Bspline_xform* bxf,         /* Output: bxf with new LUTs */
     float img_spacing[3],       /* Image spacing (in mm) */
-    int vox_per_rgn[3])         /* Knot spacing (in vox) */
+    size_t vox_per_rgn[3])         /* Knot spacing (in vox) */
 {
-    int i, j, k, p;
+    size_t i, j, k, p;
     int tx, ty, tz;
     float *A, *B, *C;
     float *Ax, *By, *Cz, *Axx, *Byy, *Czz;
@@ -570,8 +576,8 @@ void
 bspline_regularize_hessian_component (
     float out[3], 
     const Bspline_xform* bxf, 
-    int p[3], 
-    int qidx, 
+    size_t p[3], 
+    size_t qidx, 
     int derive1, 
     int derive2
 )
@@ -615,8 +621,8 @@ void
 bspline_regularize_hessian_component_b (
     float out[3], 
     const Bspline_xform* bxf, 
-    int p[3], 
-    int qidx, 
+    size_t p[3], 
+    size_t qidx, 
     float *q_lut
 )
 {
@@ -645,8 +651,8 @@ void
 bspline_regularize_hessian_update_grad (
     Bspline_score *bscore, 
     const Bspline_xform* bxf, 
-    int p[3], 
-    int qidx, 
+    size_t p[3], 
+    size_t qidx, 
     float dc_dv[3], 
     int derive1, 
     int derive2
@@ -690,8 +696,8 @@ void
 bspline_regularize_hessian_update_grad_b (
     Bspline_score *bscore, 
     const Bspline_xform* bxf, 
-    int p[3], 
-    int qidx, 
+    size_t p[3], 
+    size_t qidx, 
     float dc_dv[3], 
     float *q_lut
 )
@@ -721,8 +727,8 @@ static double
 update_score_and_grad (
     Bspline_score *bscore, 
     const Bspline_xform* bxf, 
-    int p[3], 
-    int qidx, 
+    size_t p[3], 
+    size_t qidx, 
     float grad_coeff, 
     float weight, // 2 or 1 for cross/non-cross derivatives
     float *qlut
@@ -740,7 +746,8 @@ update_score_and_grad (
 	dc_dv[d3] = weight * grad_coeff * dxyz[d3];
     }
 
-    bspline_regularize_hessian_update_grad_b (bscore, bxf, p, qidx, dc_dv, qlut);
+    bspline_regularize_hessian_update_grad_b (bscore, bxf, p, qidx, 
+	dc_dv, qlut);
 
     return score;
 }
@@ -755,12 +762,12 @@ bspline_regularize_numeric_d (
 )
 {
     double grad_score;
-    int ri, rj, rk;
-    int fi, fj, fk;
-    int p[3];
-    int q[3];
-    int qidx;
-    int num_vox;
+    size_t ri, rj, rk;
+    size_t fi, fj, fk;
+    size_t p[3];
+    size_t q[3];
+    size_t qidx;
+    size_t num_vox;
     Plm_timer timer;
     //double interval;
     float grad_coeff;
@@ -832,7 +839,7 @@ bspline_regularize_numeric_d (
 	    }
 	}
 
-	//interval = plm_timer_report (&timer);
+	bscore->time_rmetric = plm_timer_report (&timer);
 	//raw_score = grad_score / num_vox;
 	grad_score *= (parms->lambda / num_vox);
 	//printf ("        GRAD_COST %.4f   RAW_GRAD %.4f   [%.3f secs]\n", grad_score, raw_score, interval);
