@@ -66,7 +66,7 @@ CUDA_reconstruct_conebeam (
     scale = scale * options->scale;
 
     // This is just to retrieve the 2D image dimensions
-    cbi = proj_image_dir_load_image (proj_dir, 0);
+    cbi = proj_dir->load_image (0);
 
     dev_state = fdk_cuda_state_create (
                     vol, 
@@ -76,7 +76,7 @@ CUDA_reconstruct_conebeam (
                 );
 
     // Free image (we will re-load it in the main loop)
-    proj_image_destroy (cbi);
+    delete cbi;
 
     // Project each image into the volume one at a time
     for (i = 0; i < proj_dir->num_proj_images; i++)
@@ -86,7 +86,7 @@ CUDA_reconstruct_conebeam (
 #endif
 
         // load the next 2D projection
-        cbi = proj_image_dir_load_image (proj_dir, i);
+        cbi = proj_dir->load_image (i);
         pmat = cbi->pmat;
 
 #if FDK_CUDA_TIME_KERNEL
@@ -117,7 +117,7 @@ CUDA_reconstruct_conebeam (
 	);
 
         /* Free the current image */
-        proj_image_destroy ( cbi );
+        delete cbi;
 
 #if defined (VERBOSE)
         printf ("Executing kernel... ");
@@ -194,6 +194,7 @@ get_pixel_value_c (Proj_image* cbi, double r, double c)
     return cbi->img[rr*cbi->dim[0] + cc];
 }
 
+/* Nearest neighbor interpolation of intensity value on image */
 inline float
 get_pixel_value_b (Proj_image* cbi, double r, double c)
 {
@@ -211,7 +212,7 @@ get_pixel_value_b (Proj_image* cbi, double r, double c)
 void
 project_volume_onto_image_d (Volume* vol, Proj_image* cbi, float scale)
 {
-    int i, j, k, p;
+    long i, j, k, p;
     float* img = (float*) vol->img;
     double *xip, *yip, *zip;
     double acc2[3],acc3[3];
@@ -307,7 +308,7 @@ project_volume_onto_image_d (Volume* vol, Proj_image* cbi, float scale)
 void
 project_volume_onto_image_c (Volume* vol, Proj_image* cbi, float scale)
 {
-    int i, j, k;
+    long i, j, k;
     float* img = (float*) vol->img;
     double *xip, *yip, *zip;
     double sad_sid_2;
@@ -349,10 +350,10 @@ project_volume_onto_image_c (Volume* vol, Proj_image* cbi, float scale)
     /* Main loop */
 #pragma omp parallel for
     for (k = 0; k < vol->dim[2]; k++) {
-	int p = k * vol->dim[1] * vol->dim[0];
-	int j;
+	size_t p = k * vol->dim[1] * vol->dim[0];
+	size_t j;
 	for (j = 0; j < vol->dim[1]; j++) {
-	    int i;
+	    size_t i;
 	    double acc2[3];
 	    vec3_add3 (acc2, &zip[3*k], &yip[3*j]);
 	    for (i = 0; i < vol->dim[0]; i++) {
@@ -375,7 +376,7 @@ project_volume_onto_image_c (Volume* vol, Proj_image* cbi, float scale)
 void
 project_volume_onto_image_b (Volume* vol, Proj_image* cbi, float scale)
 {
-    int i, j, k, p;
+    size_t i, j, k, p;
     float* img = (float*) vol->img;
     double wip[3];
     double *xip, *yip, *zip;
@@ -452,7 +453,7 @@ project_volume_onto_image_b (Volume* vol, Proj_image* cbi, float scale)
 void
 project_volume_onto_image_a (Volume* vol, Proj_image* cbi, float scale)
 {
-    int i, j, k, p;
+    size_t i, j, k, p;
     float* img = (float*) vol->img;
     double wip[3];
     double *xip, *yip, *zip;
@@ -529,6 +530,8 @@ project_volume_onto_image_a (Volume* vol, Proj_image* cbi, float scale)
     free (zip);
 }
 
+/* Reference implementation is the most straightforward implementation, 
+    also it is the slowest */
 void
 project_volume_onto_image_reference (
     Volume* vol, 
@@ -536,13 +539,14 @@ project_volume_onto_image_reference (
     float scale
 )
 {
-    int i, j, k, p;
+    size_t i, j, k, p;
     double vp[4];   /* vp = voxel position */
     float* img = (float*) vol->img;
-    Proj_matrix *pmat = cbi->pmat;
-    
+    Proj_matrix *pmat = cbi->pmat; /* projection matrix 3D -> 2D 
+				      in homogenous coordinates */
     p = 0;
     vp[3] = 1.0;
+    /* Loop k (slices), j (rows), i (cols) */
     for (k = 0; k < vol->dim[2]; k++) {
 	vp[2] = (double) (vol->offset[2] + k * vol->spacing[2]);
 	for (j = 0; j < vol->dim[1]; j++) {
@@ -551,10 +555,11 @@ project_volume_onto_image_reference (
 		double ip[3];        /* ip = image position */
 		double s;            /* s = projection of vp onto s axis */
 		vp[0] = (double) (vol->offset[0] + i * vol->spacing[0]);
-		mat43_mult_vec3 (ip, pmat->matrix, vp);
+		mat43_mult_vec3 (ip, pmat->matrix, vp);  /* ip = matrix * vp */
 		ip[0] = pmat->ic[0] + ip[0] / ip[2];
 		ip[1] = pmat->ic[1] + ip[1] / ip[2];
-		/* Distance on axis from ctr to source */
+		/* Distance on cenral axis from voxel center to source */
+		/* pmat->nrm is normal of panel */
 		s = vec3_dot (pmat->nrm, vp);
 		/* Conebeam weighting factor */
 		s = pmat->sad - s;
@@ -565,6 +570,8 @@ project_volume_onto_image_reference (
     }
 }
 
+/* Main reconstruction loop - Loop over images, and backproject each 
+    image into the volume. */
 void
 reconstruct_conebeam (
     Volume* vol, 
@@ -578,9 +585,10 @@ reconstruct_conebeam (
     double filter_time = 0.0;
     double backproject_time = 0.0;
     double io_time = 0.0;
-    Proj_image* cbi;
+    Proj_image* cbi;    /* cbi == cone beam image */
     Plm_timer timer;
 
+    /* Arbitrary scale applied to each image */
     scale = (float) (sqrt(3.f) / (double) num_imgs);
     scale = scale * options->scale;
 
@@ -588,9 +596,10 @@ reconstruct_conebeam (
         printf ("Processing image %d\n", i);
 
         plm_timer_start (&timer);
-        cbi = proj_image_dir_load_image (proj_dir, i);
+        cbi = proj_dir->load_image (i);
         io_time += plm_timer_report (&timer);
 
+	/* Apply ramp filter */
         if (options->filter == FDK_FILTER_TYPE_RAMP) {
             plm_timer_start (&timer);
             proj_image_filter (cbi);
@@ -621,7 +630,7 @@ reconstruct_conebeam (
 
         backproject_time += plm_timer_report (&timer);
 
-        proj_image_destroy (cbi);
+        delete cbi;
     }
 
     printf ("I/O time (total) = %g\n", io_time);
