@@ -19,5 +19,6 @@ itk_image_load_char (const char* fname, Plm_image_type* original_type)
 	img = itk_image_load_any (fname, original_type, 
 	    static_cast<char>(0));
     }
-    return orient_image (img);
+    //return orient_image (img);
+    return img;
 }
